![test](https://github.com/davips/tatu/workflows/test/badge.svg)
[![codecov](https://codecov.io/gh/davips/tatu/branch/main/graph/badge.svg)](https://codecov.io/gh/davips/tatu)

# tatu - Storage of Scientific Data 
**WARNING: This project is still subject to major changes, e.g., in the next rewrite.**

<p><a href="https://commons.wikimedia.org/wiki/File:Nine-banded_Armadillo.jpg#/media/Ficheiro:Nine-banded_Armadillo.jpg"><img src="https://upload.wikimedia.org/wikipedia/commons/b/b4/Nine-banded_Armadillo.jpg" alt="Dasypus novemcinticus - CC BY 3.0 By Tomfriedel" width="320" height="193"></a></p>

# Installation

# Examples



# Grants
Part of the effort spent in the present code was kindly supported by Fapesp under supervision of
Prof. André C. P. L. F. de Carvalho at CEPID-CeMEAI (Grants 2013/07375-0 – 2019/01735-0).

# History
The novel ideias presented here are a result of a years-long
process of drafts, thinking, trial/error and rewrittings from scratch in several languages from Delphi, passing through Haskell, Java and Scala to Python - including frustration with well stablished libraries at the time. The fundamental concepts were lightly borrowed from basic category theory concepts like algebraic data structures that permeate many recent tendencies, e.g., in programming language design.

For more details, refer to https://github.com/davips/kururu
